# Contributing

PyPEEC is welcoming contributions (code, documentation, example, benchmark, test, tutorial, etc.).
For large contributions, please first discuss the changes in the issue tracker.

# Bug report

Please include a clear and concise description of what the bug is.
Ideally, provide a minimal working example for the bug.

Additionally, please report the following parameters:
* The version of PyPEEC.
* The operating system/platform/hardware.
* The version of Python and of the relevant dependencies.
* For PyVista related bugs, please include the `pyvista.Report` output.
* For NumPy related bugs, please include the `numpy.show_config` output.
* For SciPy related bugs, please include the `scipy.show_config` output.
